/*******************************************************************************
* File Name: Debounce_Int.c  
* Version 1.50
*
*  Description:
*   API for controlling the state of an interrupt.
*
*
*  Note:
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/


#include <CYDEVICE.H>
#include <CYDEVICE_TRM.H>
#include <CYLIB.H>
#include <Debounce_Int.H>


/*******************************************************************************
*  Place your includes, defines and code here 
********************************************************************************/
/* `#START Debounce_Int_intc` */

/* `#END` */


/*******************************************************************************
* Function Name: Debounce_Int_Start
********************************************************************************
* Summary:
*  Set up the interrupt and enable it.
*
* Parameters:  
*   void.
*
*
* Return:
*   void.
*
*******************************************************************************/
void Debounce_Int_Start(void)
{
    /* For all we know the interrupt is active. */
    Debounce_Int_Disable();

    /* Set the ISR to point to the Debounce_Int Interrupt. */
    Debounce_Int_SetVector(Debounce_Int_Interrupt);

    /* Set the priority. */
    Debounce_Int_SetPriority(Debounce_Int_INTC_PRIOR_NUMBER);

    /* Enable it. */
    Debounce_Int_Enable();
}

/*******************************************************************************
* Function Name: Debounce_Int_StartEx
********************************************************************************
* Summary:
*  Set up the interrupt and enable it.
*
* Parameters:  
*   address: Address of the ISR to set in the interrupt vector table.
*
*
* Return:
*   void.
*
*******************************************************************************/
void Debounce_Int_StartEx(cyisraddress address)
{
    /* For all we know the interrupt is active. */
    Debounce_Int_Disable();

    /* Set the ISR to point to the Debounce_Int Interrupt. */
    Debounce_Int_SetVector(address);

    /* Set the priority. */
    Debounce_Int_SetPriority(Debounce_Int_INTC_PRIOR_NUMBER);

    /* Enable it. */
    Debounce_Int_Enable();
}

/*******************************************************************************
* Function Name: Debounce_Int_Stop
********************************************************************************
* Summary:
*   Disables and removes the interrupt.
*
* Parameters:  
*
*
* Return:
*   void.
*
*******************************************************************************/
void Debounce_Int_Stop(void) 
{
    /* Disable this interrupt. */
    Debounce_Int_Disable();
}

/*******************************************************************************
* Function Name: Debounce_Int_Interrupt
********************************************************************************
* Summary:
*   The default Interrupt Service Routine for Debounce_Int.
*
*   Add custom code between the coments to keep the next version of this file
*   from over writting your code.
*
*
*
* Parameters:  
*
*
* Return:
*   void.
*
*******************************************************************************/
CY_ISR(Debounce_Int_Interrupt)
{
    /*  Place your Interrupt code here. */
    /* `#START Debounce_Int_Interrupt` */

    /* `#END` */

    /* PSoC3 ES1, ES2 RTC ISR PATCH  */ 
    #if(CYDEV_CHIP_FAMILY_USED == CYDEV_CHIP_FAMILY_PSOC3)
        #if((CYDEV_CHIP_REVISION_USED <= CYDEV_CHIP_REVISION_3A_ES2) && (Debounce_Int__ES2_PATCH ))      
            Debounce_Int_ISR_PATCH();
        #endif
    #endif
}

/*******************************************************************************
* Function Name: Debounce_Int_SetVector
********************************************************************************
* Summary:
*   Change the ISR vector for the Interrupt. Note calling Debounce_Int_Start
*   will override any effect this method would have had. To set the vector before
*   the component has been started use Debounce_Int_StartEx instead.
*
*
* Parameters:
*   address: Address of the ISR to set in the interrupt vector table.
*
*
* Return:
*   void.
*
*
*******************************************************************************/
void Debounce_Int_SetVector(cyisraddress address) 
{
    CY_SET_REG16(Debounce_Int_INTC_VECTOR, (uint16) address);
}

/*******************************************************************************
* Function Name: Debounce_Int_GetVector
********************************************************************************
* Summary:
*   Gets the "address" of the current ISR vector for the Interrupt.
*
*
* Parameters:
*   void.
*
*
* Return:
*   Address of the ISR in the interrupt vector table.
*
*
*******************************************************************************/
cyisraddress Debounce_Int_GetVector(void) 
{
    return (cyisraddress) CY_GET_REG16(Debounce_Int_INTC_VECTOR);
}

/*******************************************************************************
* Function Name: Debounce_Int_SetPriority
********************************************************************************
* Summary:
*   Sets the Priority of the Interrupt. Note calling Debounce_Int_Start
*   or Debounce_Int_StartEx will override any effect this method would have had. 
*	This method should only be called after Debounce_Int_Start or 
*	Debounce_Int_StartEx has been called. To set the initial
*	priority for the component use the cydwr file in the tool.
*
*
* Parameters:
*   priority: Priority of the interrupt. 0 - 7, 0 being the highest.
*
*
* Return:
*   void.
*
*
*******************************************************************************/
void Debounce_Int_SetPriority(uint8 priority) 
{
    *Debounce_Int_INTC_PRIOR = priority << 5;
}

/*******************************************************************************
* Function Name: Debounce_Int_GetPriority
********************************************************************************
* Summary:
*   Gets the Priority of the Interrupt.
*
*
* Parameters:
*   void.
*
*
* Return:
*   Priority of the interrupt. 0 - 7, 0 being the highest.
*
*
*******************************************************************************/
uint8 Debounce_Int_GetPriority(void) 
{
    uint8 priority;


    priority = *Debounce_Int_INTC_PRIOR >> 5;

    return priority;
}

/*******************************************************************************
* Function Name: Debounce_Int_Enable
********************************************************************************
* Summary:
*   Enables the interrupt.
*
*
* Parameters:
*   void.
*
*
* Return:
*   void.
*
*
*******************************************************************************/
void Debounce_Int_Enable(void) 
{
    /* Enable the general interrupt. */
    *Debounce_Int_INTC_SET_EN = Debounce_Int__INTC_MASK;
}

/*******************************************************************************
* Function Name: Debounce_Int_GetState
********************************************************************************
* Summary:
*   Gets the state (enabled, disabled) of the Interrupt.
*
*
* Parameters:
*   void.
*
*
* Return:
*   1 if enabled, 0 if disabled.
*
*
*******************************************************************************/
uint8 Debounce_Int_GetState(void) 
{
    /* Get the state of the general interrupt. */
    return (*Debounce_Int_INTC_SET_EN & Debounce_Int__INTC_MASK) ? 1:0;
}

/*******************************************************************************
* Function Name: Debounce_Int_Disable
********************************************************************************
* Summary:
*   Disables the Interrupt.
*
*
* Parameters:
*   void.
*
*
* Return:
*   void.
*
*
*******************************************************************************/
void Debounce_Int_Disable(void) 
{
    /* Disable the general interrupt. */
    *Debounce_Int_INTC_CLR_EN = Debounce_Int__INTC_MASK;
}

/*******************************************************************************
* Function Name: Debounce_Int_SetPending
********************************************************************************
* Summary:
*   Causes the Interrupt to enter the pending state, a software method of
*   generating the interrupt.
*
*
* Parameters:
*   void.
*
*
* Return:
*   void.
*
*
*******************************************************************************/
void Debounce_Int_SetPending(void) 
{
    *Debounce_Int_INTC_SET_PD = Debounce_Int__INTC_MASK;
}

/*******************************************************************************
* Function Name: Debounce_Int_ClearPending
********************************************************************************
* Summary:
*   Clears a pending interrupt.
*
* Parameters:
*   void.
*
*
* Return:
*   void.
*
*
*******************************************************************************/
void Debounce_Int_ClearPending(void) 
{
    *Debounce_Int_INTC_CLR_PD = Debounce_Int__INTC_MASK;
}
