/*******************************************************************************
* File Name: KBD_OutPins.c  
* Version 1.50
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#include "cytypes.h"
#include "KBD_OutPins.h"


/*******************************************************************************
* Function Name: KBD_OutPins_Write
********************************************************************************
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  void 
*  
*******************************************************************************/
void KBD_OutPins_Write(uint8 value) 
{
    uint8 staticBits = KBD_OutPins_DR & ~KBD_OutPins_MASK;
    KBD_OutPins_DR = staticBits | ((value << KBD_OutPins_SHIFT) & KBD_OutPins_MASK);
}


/*******************************************************************************
* Function Name: KBD_OutPins_SetDriveMode
********************************************************************************
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  void
*
*******************************************************************************/
void KBD_OutPins_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(KBD_OutPins_0, mode);
	CyPins_SetPinDriveMode(KBD_OutPins_1, mode);
	CyPins_SetPinDriveMode(KBD_OutPins_2, mode);
}


/*******************************************************************************
* Function Name: KBD_OutPins_Read
********************************************************************************
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro KBD_OutPins_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 KBD_OutPins_Read(void) 
{
    return (KBD_OutPins_PS & KBD_OutPins_MASK) >> KBD_OutPins_SHIFT;
}


/*******************************************************************************
* Function Name: KBD_OutPins_ReadDataReg
********************************************************************************
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 KBD_OutPins_ReadDataReg(void) 
{
    return (KBD_OutPins_DR & KBD_OutPins_MASK) >> KBD_OutPins_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(KBD_OutPins_INTSTAT) 

    /*******************************************************************************
    * Function Name: KBD_OutPins_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  void 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 KBD_OutPins_ClearInterrupt(void) 
    {
        return (KBD_OutPins_INTSTAT & KBD_OutPins_MASK) >> KBD_OutPins_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */ 
