/*******************************************************************************
* File Name: KBD_ROWPins.c  
* Version 1.50
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#include "cytypes.h"
#include "KBD_ROWPins.h"


/*******************************************************************************
* Function Name: KBD_ROWPins_Write
********************************************************************************
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  void 
*  
*******************************************************************************/
void KBD_ROWPins_Write(uint8 value) 
{
    uint8 staticBits = KBD_ROWPins_DR & ~KBD_ROWPins_MASK;
    KBD_ROWPins_DR = staticBits | ((value << KBD_ROWPins_SHIFT) & KBD_ROWPins_MASK);
}


/*******************************************************************************
* Function Name: KBD_ROWPins_SetDriveMode
********************************************************************************
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  void
*
*******************************************************************************/
void KBD_ROWPins_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(KBD_ROWPins_0, mode);
	CyPins_SetPinDriveMode(KBD_ROWPins_1, mode);
	CyPins_SetPinDriveMode(KBD_ROWPins_2, mode);
	CyPins_SetPinDriveMode(KBD_ROWPins_3, mode);
}


/*******************************************************************************
* Function Name: KBD_ROWPins_Read
********************************************************************************
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro KBD_ROWPins_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 KBD_ROWPins_Read(void) 
{
    return (KBD_ROWPins_PS & KBD_ROWPins_MASK) >> KBD_ROWPins_SHIFT;
}


/*******************************************************************************
* Function Name: KBD_ROWPins_ReadDataReg
********************************************************************************
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 KBD_ROWPins_ReadDataReg(void) 
{
    return (KBD_ROWPins_DR & KBD_ROWPins_MASK) >> KBD_ROWPins_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(KBD_ROWPins_INTSTAT) 

    /*******************************************************************************
    * Function Name: KBD_ROWPins_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  void 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 KBD_ROWPins_ClearInterrupt(void) 
    {
        return (KBD_ROWPins_INTSTAT & KBD_ROWPins_MASK) >> KBD_ROWPins_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */ 
